==> side_menu_v1.17.0.zip: side_menu/l10n/fr.js <==
OC.L10N.register("side_menu", {
    "Custom menu": "Menu personnalisé",
    "Enable the custom menu": "Activer le menu personnalisé",
    "No": "Non",
    "Yes": "Oui",
    "Menu": "Menu",
    "Use the shortcut <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "Utiliser le raccourcis clavier <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> pour ouvrir et fermer le menu latéral. Utiliser <span class=\"keyboard-key\">tab<\/span> pour naviguer.",
    "Top menu": "Menu supérieur",
    "Apps that not must be moved in the side menu": "Les applications qui ne doivent pas être affichées dans le menu latéral",
    "If there is no selection then the global configuration is applied.": "Si il n'y a aucune sélection alors la configuration globale sera appliquée",
    "Experimental": "Expérimental",
    "Save": "Sauvegarder",
    "You like this app and you want to support me?": "Vous aimer cette application et vous souhaitez m'aider ?",
    "Buy me a coffee ☕": "Offrez moi un café ☕",
    "Hidden": "Caché",
    "Small": "Petit",
    "Normal": "Normal",
    "Big": "Gros",
    "Colors": "Couleurs",
    "Background color": "Couleur de fond",
    "Background color of current app": "Couleur de fond de l'application en cours",
    "Text color": "Couleur du texte",
    "Loader": "Indicateur de chargement",
    "Icon": "Icône",
    "Same color": "Même couleur",
    "Opposite color": "Couleur opposée",
    "Transparent": "Transparent",
    "Opaque": "Opaque",
    "Opener": "Bouton d'ouverture",
    "Default": "Par défaut",
    "Default (dark)": "Par défaut (sombre)",
    "Hamburger": "Hamburger",
    "Hamburger (dark)": "Hamburger (sombre)",
    "Hamburger 2": "Hamburger 2",
    "Hamburger 2 (dark)": "Hamburger 2 (sombre)",
    "Before the logo": "Avant le logo",
    "After the logo": "Après le logo",
    "Position": "Position",
    "Show only the opener (hidden logo)": "Afficher uniquement le bouton d'ouverture (masquer le logo)",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "Ne pas afficher le menu latéral et le bouton d'ouverture s'il n'y a aucune application (exemple : page publiques).",
    "Panel": "Panneau",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "Ouvrir le menu au passage de la souris (automatiquement désactivé sur les écrans tactiles)",
    "Display the big menu": "Afficher le menu large",
    "The big menu is not compatible with AppOrder.": "Le menu large n'est pas compatible avec l'application AppOrder",
    "Display the logo": "Afficher le logo",
    "This feature is not compatible with the <code>big menu<\/code> display.": "Cette fonctionnalité n'est pas compatible avec l'affichage du menu large.",
    "Icons and texts": "Icônes et textes",
    "Loader enabled": "Activation de l'indicateur de chargement",
    "Tips": "Astuces",
    "Always displayed": "Toujours affiché",
    "The logo will be hidden when the menu is always displayed.": "Le logo sera masque si le menu est toujours affiché.",
    "This is the automatic behavior when the menu is always displayed.": "C'est le comportement automatique lorsque le menu est toujours affiché.",
    "Not compatible with touch screens.": "Incompatible avec les écrans tactiles.",
    "Big menu": "Menu large",
    "Live preview": "Aperçu en direct",
    "Open apps in new tab": "Ouvrir les applications dans un nouvel onglet",
    "Use the global setting": "Utiliser la configuration globale",
    "Use my selection": "Utiliser ma sélection",
    "Show and hide the list of applications": "Afficher et masquer la liste des applications",
    "Use the avatar instead of the logo": "Utiliser l'avatar à la place du logo",
    "You do not have permission to change the settings.": "Vous n'avez pas la permission de changer les paramètres.",
    "Force this configuration to users": "Forcer cette configuration aux utilisateurs",
    "Export the configuration": "Exporter la configuration",
    "Purge the cache": "Purger le cache"
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> side_menu_v1.20.0.zip: side_menu/l10n/fr.js <==
OC.L10N.register("side_menu", {
    "Custom menu": "Menu personnalisé",
    "Enable the custom menu": "Activer le menu personnalisé",
    "No": "Non",
    "Yes": "Oui",
    "Menu": "Menu",
    "Use the shortcut <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "Utiliser le raccourcis clavier <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> pour ouvrir et fermer le menu latéral. Utiliser <span class=\"keyboard-key\">tab<\/span> pour naviguer.",
    "Top menu": "Menu supérieur",
    "Apps that not must be moved in the side menu": "Les applications qui ne doivent pas être affichées dans le menu latéral",
    "If there is no selection then the global configuration is applied.": "Si il n'y a aucune sélection alors la configuration globale sera appliquée",
    "Experimental": "Expérimental",
    "Save": "Sauvegarder",
    "You like this app and you want to support me?": "Vous aimer cette application et vous souhaitez m'aider ?",
    "Buy me a coffee ☕": "Offrez moi un café ☕",
    "Hidden": "Caché",
    "Small": "Petit",
    "Normal": "Normal",
    "Big": "Gros",
    "Colors": "Couleurs",
    "Background color": "Couleur de fond",
    "Background color of current app": "Couleur de fond de l'application en cours",
    "Text color": "Couleur du texte",
    "Loader": "Indicateur de chargement",
    "Icon": "Icône",
    "Same color": "Même couleur",
    "Opposite color": "Couleur opposée",
    "Transparent": "Transparent",
    "Opaque": "Opaque",
    "Opener": "Bouton d'ouverture",
    "Default": "Par défaut",
    "Default (dark)": "Par défaut (sombre)",
    "Hamburger": "Hamburger",
    "Hamburger (dark)": "Hamburger (sombre)",
    "Hamburger 2": "Hamburger 2",
    "Hamburger 2 (dark)": "Hamburger 2 (sombre)",
    "Before the logo": "Avant le logo",
    "After the logo": "Après le logo",
    "Position": "Position",
    "Show only the opener (hidden logo)": "Afficher uniquement le bouton d'ouverture (masquer le logo)",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "Ne pas afficher le menu latéral et le bouton d'ouverture s'il n'y a aucune application (exemple : page publiques).",
    "Panel": "Panneau",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "Ouvrir le menu au passage de la souris (automatiquement désactivé sur les écrans tactiles)",
    "Display the big menu": "Afficher le menu large",
    "The big menu is not compatible with AppOrder.": "Le menu large n'est pas compatible avec l'application AppOrder",
    "Display the logo": "Afficher le logo",
    "This feature is not compatible with the <code>big menu<\/code> display.": "Cette fonctionnalité n'est pas compatible avec l'affichage du menu large.",
    "Icons and texts": "Icônes et textes",
    "Loader enabled": "Activation de l'indicateur de chargement",
    "Tips": "Astuces",
    "Always displayed": "Toujours affiché",
    "The logo will be hidden when the menu is always displayed.": "Le logo sera masque si le menu est toujours affiché.",
    "This is the automatic behavior when the menu is always displayed.": "C'est le comportement automatique lorsque le menu est toujours affiché.",
    "Not compatible with touch screens.": "Incompatible avec les écrans tactiles.",
    "Big menu": "Menu large",
    "Live preview": "Aperçu en direct",
    "Open apps in new tab": "Ouvrir les applications dans un nouvel onglet",
    "Use the global setting": "Utiliser la configuration globale",
    "Use my selection": "Utiliser ma sélection",
    "Show and hide the list of applications": "Afficher et masquer la liste des applications",
    "Use the avatar instead of the logo": "Utiliser l'avatar à la place du logo",
    "You do not have permission to change the settings.": "Vous n'avez pas la permission de changer les paramètres.",
    "Force this configuration to users": "Forcer cette configuration aux utilisateurs",
    "Export the configuration": "Exporter la configuration",
    "Purge the cache": "Purger le cache",
    "Show the link to settings": "Afficher le lien vers les paramètres",
    "The menu is enabled by default for users": "Le menu est activé par défaut pour les utilisateurs",
    "Except when the configuration is forced.": "Sauf lorsque la configuration est forcée."
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
